@@ -21,6 +21,7 @@ def parse_args(action, usage) -> argparse.Namespace:
     parser.add_argument("--safe", "-safe", action="store_true", help="Skip generic URLs")
     parser.add_argument("--no-sanitize", "-s", action="store_true", help="Don't sanitize some common URL parameters")
     parser.add_argument("--extra", "-extra", action="store_true", help="Get full metadata (takes a lot longer)")
+    parser.add_argument("--playlist-files", action="store_true", help="Read playlists from text files")
     parser.add_argument("--extra-media-data", default={})
     parser.add_argument("--extra-playlist-data", default={})
     parser.add_argument("--ignore-errors", "--ignoreerrors", "-i", action="store_true", help=argparse.SUPPRESS)
@@ -45,7 +46,7 @@ def parse_args(action, usage) -> argparse.Namespace:
     args.db = db.connect(args)
 
     if hasattr(args, "no_sanitize") and hasattr(args, "playlists") and not args.no_sanitize:
-        args.playlists = [consts.sanitize_url(args, p) for p in args.playlists]
+        args.playlists = [utils.sanitize_url(args, p) for p in args.playlists]
     if hasattr(args, "playlists"):
         args.playlists = utils.conform(args.playlists)
     log.info(utils.dict_filter_bool(args.__dict__))
@@ -85,9 +86,12 @@ def tube_add(args=None) -> None:
         library tubeupdate tw.db --extra
     """,
     )
+    if args.playlist_files:
+        args.playlists = utils.flatten([Path(p).read_text().splitlines() for p in args.playlists])
+
     for path in args.playlists:
         if args.safe and not tube_backend.is_supported(path):
-            log.warning("[%s]: Unsupported playlist (safe_mode)", path)
+            log.info("[%s]: Unsupported playlist (safe_mode)", path)
             continue
 
         tube_backend.process_playlist(args, path, tube_backend.tube_opts(args))
